@@ -87,6 +87,7 @@
       {"bleu"         ,1, _BLUE, _INT_COLOR ,T_NUMBER},
       {"blue"         ,1, _BLUE, _INT_COLOR ,T_NUMBER},
       {"brent_solver"         ,1, _BRENT_SOLVER, _INT_SOLVER,T_NUMBER},
+      {"brown"         ,1, 47624, _INT_COLOR ,T_NUMBER},
       {"by",1,0,0,T_BY},
       {"cap_flat_line"         ,1, _CAP_FLAT_LINE, _INT_COLOR ,T_NUMBER},
       {"cap_round_line"         ,1, _CAP_ROUND_LINE, _INT_COLOR ,T_NUMBER},
@@ -103,6 +104,7 @@
       {"dash_line"         ,1, _DASH_LINE, _INT_COLOR ,T_NUMBER},
       {"dashdot_line"         ,1, _DASHDOT_LINE, _INT_COLOR ,T_NUMBER},
       {"dashdotdot_line"         ,1, _DASHDOTDOT_LINE, _INT_COLOR ,T_NUMBER},
+      {"de",0,0,0,T_FROM},
       {"default",1,0,0,T_DEFAULT},
       {"directed",0,    _GT_DIRECTED, _INT_MAPLECONVERSION,T_TYPE_ID},
       {"dnewton_solver"         ,1, _DNEWTON_SOLVER, _INT_SOLVER,T_NUMBER},
@@ -151,6 +153,7 @@
       {"filled"         ,1, _FILL_POLYGON, _INT_COLOR ,T_NUMBER},
       {"float"                ,0, _DOUBLE_, _INT_TYPE, T_TYPE_ID},
       {"font"         ,1,_FONT , _INT_PLOT ,T_NUMBER},
+      {"for",0,2,0,T_FOR},
       {"fpour",0,2,0,T_BLOC_END},
       {"frames"         ,1,_FRAMES , _INT_PLOT ,T_NUMBER},
       {"from",0,0,0,T_FROM},
@@ -230,12 +233,14 @@
       {"golub_reinsch_mod_decomp"         ,1, _GOLUB_REINSCH_MOD_DECOMP, _INT_SOLVER,T_NUMBER},
       {"gomme"         ,1, _WHITE, /* was 49 */ _INT_COLOR ,T_NUMBER},
       {"green"         ,1, _GREEN, _INT_COLOR ,T_NUMBER},
+      {"grey"         ,1, 44373, _INT_COLOR ,T_NUMBER},
       {"groebner",1,_GROEBNER,_INT_MAPLELIB,T_MAPLELIB},
       {"hybrid_solver"         ,1, _HYBRID_SOLVER, _INT_SOLVER,T_NUMBER},
       {"hybridj_solver"         ,1, _HYBRIDJ_SOLVER, _INT_SOLVER,T_NUMBER},
       {"hybrids_solver"         ,1, _HYBRIDS_SOLVER, _INT_SOLVER,T_NUMBER},
       {"hybridsj_solver"         ,1, _HYBRIDSJ_SOLVER, _INT_SOLVER,T_NUMBER},
       {"identifier"            ,0, _IDNT, _INT_TYPE, T_TYPE_ID},
+      {"if",0,2,0,T_IF},
       {"in",0,0,0,T_IN},
       {"integer"               ,0, _ZINT, _INT_TYPE, T_TYPE_ID},
       {"intersect",0,0,0,T_INTERSECT},
@@ -244,6 +249,7 @@
       {"jaune"         ,1, _YELLOW, _INT_COLOR ,T_NUMBER},
       {"jusqu_a",0,0,0,T_UNTIL},
       {"jusqua",0,0,0,T_UNTIL},
+      {"jusque",0,1,0,T_TO},
       {"keep_pivot"         ,1, _KEEP_PIVOT, _INT_SOLVER,T_NUMBER},
       {"labeldirections"         ,1, _LABELDIRECTIONS, _INT_PLOT ,T_NUMBER},
       {"labelfont"         ,1, _LABELFONT, _INT_PLOT ,T_NUMBER},
@@ -322,8 +328,10 @@
       {"numtheory",1,_NUMTHEORY,_INT_MAPLELIB,T_MAPLELIB},
       {"od",0,9,0,T_BLOC_END},
       {"of",0,0,0,T_OF},
+      {"orange"         ,1, 64800, _INT_COLOR ,T_NUMBER},
       {"otherwise",0,0,0,T_DEFAULT},
       {"parfrac"         ,1,_PARFRAC , _INT_MAPLECONVERSION ,T_NUMBER},
+      {"pink"         ,1, 65017, _INT_COLOR ,T_NUMBER},
       {"planar",0,    _GT_PLANAR, _INT_MAPLECONVERSION,T_TYPE_ID},
       {"plex"         ,1,_PLEX_ORDER , _INT_GROEBNER ,T_NUMBER},
       {"plus_point"         ,1, _POINT_PLUS , _INT_COLOR ,T_NUMBER},
@@ -348,6 +356,7 @@
       {"posint"               ,0, _POSINT, _INT_MAPLECONVERSION, T_TYPE_ID},
       {"proc",0,0,0,T_PROC},
       {"program",0,0,0,T_PROGRAM},
+      {"purple"         ,1, 43029, _INT_COLOR ,T_NUMBER},
       {"quadrant1"         ,1, _QUADRANT1 , _INT_COLOR ,T_NUMBER},
       {"quadrant2"         ,1, _QUADRANT2 , _INT_COLOR ,T_NUMBER},
       {"quadrant3"         ,1, _QUADRANT3 , _INT_COLOR ,T_NUMBER},
@@ -359,6 +368,7 @@
       {"red"         ,1, _RED, _INT_COLOR ,T_NUMBER},
       {"rempli"         ,1, _FILL_POLYGON , _INT_COLOR ,T_NUMBER},
       {"resolution"         ,1,_RESOLUTION , _INT_PLOT ,T_NUMBER},
+      {"return",0,2,0,T_RETURN},
       {"revlex"         ,1,_REVLEX_ORDER , _INT_GROEBNER ,T_NUMBER},
       {"rhombus_point"         ,1, _POINT_LOSANGE , _INT_COLOR ,T_NUMBER},
       {"right_rectangle"         ,1, _RECTANGLE_DROIT, _INT_SOLVER,T_NUMBER},
@@ -412,6 +422,7 @@
       {"vstep"         ,1, _VSTEP , _INT_PLOT ,T_NUMBER},
       {"weighted",0,    _GT_WEIGHTED, _INT_MAPLECONVERSION,T_TYPE_ID},
       {"weights",0,    _GT_WEIGHTS, _INT_MAPLECONVERSION,T_TYPE_ID},
+      {"while",0,2,0,T_WHILE},
       {"with_cocoa"         ,1,_WITH_COCOA , _INT_GROEBNER ,T_NUMBER},
       {"with_f5"         ,1,_WITH_F5 , _INT_GROEBNER ,T_NUMBER},
       {"xstep"         ,1, _XSTEP , _INT_PLOT ,T_NUMBER},
